.. -*- mode: rst; fill-column: 79 -*-
.. ex: set sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the NiBabel package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. _chap_devdiscuss:

*********************
Developer discussions
*********************

Some discussions of usecases and other design issues.  Most of these don't apply
to the current codebase, and are only for discussion of future directions.

.. toctree::
    :maxdepth: 2

    usecases/index
    refactoring/index
    data_pkg_design
